@@ -24,25 +24,25 @@ fn main()
   noecho();
 
   /* Prompt for a character. */
-  addstr("Enter a character: ").unwrap();
+  addstr("Enter a character: ");
 
   /* Wait for input. */
   let ch = getch();
-  if ch == KEY_F(1)
+  if ch == KEY_F1
   {
     /* Enable attributes and output message. */
-    attron(A_BOLD | A_BLINK);
-    addstr("\nF1").unwrap();
-    attroff(A_BOLD | A_BLINK);
-    addstr(" pressed").unwrap();
+    attron(A_BOLD() | A_BLINK());
+    addstr("\nF1");
+    attroff(A_BOLD() | A_BLINK());
+    addstr(" pressed");
   }
   else
   {
     /* Enable attributes and output message. */
-    addstr("\nKey pressed: ").unwrap();
-    attron(A_BOLD | A_BLINK);
-    addstr(format!("{}\n", char::from_u32(ch as u32).expect("Invalid char")).as_ref()).unwrap();
-    attroff(A_BOLD | A_BLINK);
+    addstr("\nKey pressed: ");
+    attron(A_BOLD() | A_BLINK());
+    addstr(format!("{}\n", char::from_u32(ch as u32).expect("Invalid char")).as_ref());
+    attroff(A_BOLD() | A_BLINK());
   }
 
   /* Refresh, showing the previous message. */
