@@ -153,7 +153,7 @@ extern {
     pub fn mvinsnstr(_:c_int, _:c_int, _:char_p, _:c_int) -> c_int;
     pub fn mvinsstr(_:c_int, _:c_int, _:char_p) -> c_int;
     pub fn mvinstr(_:c_int, _:c_int, _:char_p) -> c_int;
-    pub fn mvprintw(_:c_int, _:c_int, fmt: char_p, _:char_p) -> c_int;
+    pub fn mvprintw(_:c_int, _:c_int, _:char_p) -> c_int;
     //  fn mvscanw(_:c_int,_:c_int, _:char_p) -> c_int;
     pub fn mvvline(_:c_int, _:c_int, _:chtype, _:c_int) -> c_int;
     pub fn mvwaddch(_:WINDOW, _:c_int, _:c_int, _:chtype) -> c_int;
@@ -176,7 +176,7 @@ extern {
     pub fn mvwinsnstr(_:WINDOW, _:c_int, _:c_int, _:char_p, _:c_int) -> c_int;
     pub fn mvwinsstr(_:WINDOW, _:c_int, _:c_int, _:char_p) -> c_int;
     pub fn mvwinstr(_:WINDOW, _:c_int, _:c_int, _:char_p) -> c_int;
-    pub fn mvwprintw(_:WINDOW, _:c_int, _:c_int, fmt: char_p, _:char_p) -> c_int;
+    pub fn mvwprintw(_:WINDOW, _:c_int, _:c_int, _:char_p) -> c_int;
 
     //  fn mvwscanw(_:WINDOW, _:c_int, _:c_int, _:char_p) -> c_int;
     pub fn mvwvline(_:WINDOW, _:c_int, _:c_int, _:chtype, _:c_int) -> c_int;
@@ -200,7 +200,7 @@ extern {
     pub fn pnoutrefresh(_:WINDOW,_:c_int,_:c_int,_:c_int,_:c_int,_:c_int,_:c_int) -> c_int;
     pub fn prefresh(_:WINDOW,_:c_int,_:c_int,_:c_int,_:c_int,_:c_int,_:c_int) -> c_int;
 
-    pub fn printw(fmt: char_p, _:char_p) -> c_int;
+    pub fn printw(_:char_p) -> c_int;
     pub fn putwin(_:WINDOW, _:FILE_p) -> c_int;
     pub fn qiflush();
     pub fn raw() -> c_int;
@@ -311,7 +311,7 @@ extern {
     pub fn winstr(_:WINDOW, _:char_p) -> c_int;
     pub fn wmove(_:WINDOW,_:c_int,_:c_int) -> c_int;
     pub fn wnoutrefresh(_:WINDOW) -> c_int;
-    pub fn wprintw(_:WINDOW, fmt: char_p, _:char_p) -> c_int;
+    pub fn wprintw(_:WINDOW, _:char_p) -> c_int;
     pub fn wredrawln(_:WINDOW,_:c_int,_:c_int) -> c_int;
     pub fn wrefresh(_:WINDOW) -> c_int;
     pub fn wresize(_:WINDOW, _:c_int, _:c_int) -> c_int;
@@ -376,51 +376,6 @@ extern {
     pub fn mouseinterval(_:c_int) -> c_int;
     pub fn wmouse_trafo(_:WINDOW,_:*mut c_int,_:*mut c_int,_:c_bool) -> c_bool;
     pub fn mouse_trafo(_:*mut c_int,_:*mut c_int,_:c_bool) -> c_bool;
-
-    pub fn impl_ACS_ULCORNER() -> chtype;
-    pub fn impl_ACS_LLCORNER() -> chtype;
-    pub fn impl_ACS_URCORNER() -> chtype;
-    pub fn impl_ACS_LRCORNER() -> chtype;
-    pub fn impl_ACS_LTEE() -> chtype;
-    pub fn impl_ACS_RTEE() -> chtype;
-    pub fn impl_ACS_BTEE() -> chtype;
-    pub fn impl_ACS_TTEE() -> chtype;
-    pub fn impl_ACS_HLINE() -> chtype;
-    pub fn impl_ACS_VLINE() -> chtype;
-    pub fn impl_ACS_PLUS() -> chtype;
-    pub fn impl_ACS_S1() -> chtype;
-    pub fn impl_ACS_S9() -> chtype;
-    pub fn impl_ACS_DIAMOND() -> chtype;
-    pub fn impl_ACS_CKBOARD() -> chtype;
-    pub fn impl_ACS_DEGREE() -> chtype;
-    pub fn impl_ACS_PLMINUS() -> chtype;
-    pub fn impl_ACS_BULLET() -> chtype;
-    pub fn impl_ACS_LARROW() -> chtype;
-    pub fn impl_ACS_RARROW() -> chtype;
-    pub fn impl_ACS_DARROW() -> chtype;
-    pub fn impl_ACS_UARROW() -> chtype;
-    pub fn impl_ACS_BOARD() -> chtype;
-    pub fn impl_ACS_LANTERN() -> chtype;
-    pub fn impl_ACS_BLOCK() -> chtype;
-    pub fn impl_ACS_S3() -> chtype;
-    pub fn impl_ACS_S7() -> chtype;
-    pub fn impl_ACS_LEQUAL() -> chtype;
-    pub fn impl_ACS_GEQUAL() -> chtype;
-    pub fn impl_ACS_PI() -> chtype;
-    pub fn impl_ACS_NEQUAL() -> chtype;
-    pub fn impl_ACS_STERLING() -> chtype;
-    pub fn impl_ACS_BSSB() -> chtype;
-    pub fn impl_ACS_SSBB() -> chtype;
-    pub fn impl_ACS_BBSS() -> chtype;
-    pub fn impl_ACS_SBBS() -> chtype;
-    pub fn impl_ACS_SBSS() -> chtype;
-    pub fn impl_ACS_SSSB() -> chtype;
-    pub fn impl_ACS_SSBS() -> chtype;
-    pub fn impl_ACS_BSSS() -> chtype;
-    pub fn impl_ACS_BSBS() -> chtype;
-    pub fn impl_ACS_SBSB() -> chtype;
-    pub fn impl_ACS_SSSS() -> chtype;
-    
 }
 
 /// Extended color support. Requires ncurses6.
