@@ -132,6 +132,7 @@
 //! [reqwest-docs]: https://docs.rs/reqwest/
 //! [reqwest-proxies]: https://docs.rs/reqwest/#proxies
 //! [ureq-docs]: https://docs.rs/ureq/
+//! [ureq-proxying]: https://docs.rs/ureq/latest/ureq/struct.Proxy.html
 //! [examples-github]: https://github.com/ramsayleung/rspotify/tree/master/examples
 //! [spotify-main]: https://developer.spotify.com/documentation/web-api/
 //! [spotify-auth-flows]: https://developer.spotify.com/documentation/general/guides/authorization/
@@ -171,7 +172,6 @@ use std::{
 };
 
 use base64::{engine::general_purpose, Engine as _};
-use getrandom::getrandom;
 use thiserror::Error;
 
 pub mod prelude {
@@ -348,7 +348,7 @@ impl Default for Config {
 /// secure random data, ideally backed by hardware entropy sources.
 pub(crate) fn generate_random_string(length: usize, alphabet: &[u8]) -> String {
     let mut buf = vec![0u8; length];
-    getrandom(&mut buf).unwrap();
+    getrandom::fill(&mut buf).unwrap();
     let range = alphabet.len();
 
     buf.iter()
